@@ -8,7 +8,7 @@ package org.tanukisoftware.wrapper;
  * This software is the proprietary information of Tanuki Software.
  * You shall use it only in accordance with the terms of the
  * license agreement you entered into with Tanuki Software.
- * http://wrapper.tanukisoftware.org/doc/english/licenseOverview.html
+ * http://wrapper.tanukisoftware.com/doc/english/licenseOverview.html
  */
 
 import java.io.IOException;
@@ -155,7 +155,7 @@ public class WrapperActionServer
     {
         if ( Thread.currentThread() != m_runner )
         {
-            throw new IllegalStateException( "Private method." );
+            throw new IllegalStateException(WrapperManager.getRes().getString( "Private method." ) );
         }
         
         try
@@ -196,7 +196,7 @@ public class WrapperActionServer
                             }
                             catch ( Throwable t )
                             {
-                                m_out.println( "Error processing action." );
+                                m_out.println( WrapperManager.getRes().getString( "Error processing action." ) );
                                 t.printStackTrace( m_out );
                             }
                         }
@@ -216,7 +216,7 @@ public class WrapperActionServer
                     }
                     else
                     {
-                        m_out.println( "Unexpeced error." );
+                        m_out.println( WrapperManager.getRes().getString( "Unexpeced error." ) );
                         t.printStackTrace( m_out );
                         
                         // Avoid tight thrashing
@@ -457,7 +457,7 @@ public class WrapperActionServer
                         }
                         catch ( NoSuchMethodException e )
                         {
-                            m_out.println( "halt not supported by current JVM." );
+                            m_out.println( WrapperManager.getRes().getString( "halt not supported by current JVM." ) );
                             haltMethod = null;
                         }
                         
@@ -470,13 +470,13 @@ public class WrapperActionServer
                             }
                             catch ( IllegalAccessException e )
                             {
-                                m_out.println(
-                                    "Unable to call runitme.halt: " + e.getMessage() );
+                                m_out.println( WrapperManager.getRes().getString(
+                                    "Unable to call runitme.halt: {0}", e.getMessage() ) );
                             }
                             catch ( InvocationTargetException e )
                             {
-                                m_out.println(
-                                    "Unable to call runitme.halt: " + e.getMessage() );
+                                m_out.println( WrapperManager.getRes().getString( 
+                                    "Unable to call runitme.halt: {0}", e.getMessage() ) );
                             }
                         }
                     }
